@@ -3,6 +3,6 @@ import excep
 
 Pyro4.Daemon.serveSimple(
     {
-        excep.TestClass(): "example.exceptions"
+        excep.TestClass: "example.exceptions"
     },
     ns=True, verbose=True)
