@@ -4,6 +4,7 @@ import os
 import Pyro4
 
 
+@Pyro4.expose
 class Thingy(object):
     def message(self, arg):
         print("Message received:", arg)
@@ -12,7 +13,8 @@ class Thingy(object):
 
 if os.path.exists("example_unix.sock"):
     os.remove("example_unix.sock")
-d = Pyro4.Daemon(unixsocket="example_unix.sock")
-uri = d.register(Thingy(), "example.unixsock")
-print("Server running, uri=", uri)
-d.requestLoop()
+
+with Pyro4.Daemon(unixsocket="example_unix.sock") as d:
+    uri = d.register(Thingy, "example.unixsock")
+    print("Server running, uri=", uri)
+    d.requestLoop()
